@@ -24,7 +24,6 @@
 //!
 
 
-use serde_json;
 use serde_urlencoded;
 
 use BuildQuery;
@@ -32,6 +31,8 @@ use Projects;
 
 use groups::ProjectsListerInternal;
 
+use ::errors::*;
+
 
 #[derive(Debug, Clone)]
 pub struct ProjectsLister<'a> {
@@ -90,13 +91,11 @@ impl<'a> ProjectsLister<'a> {
 
 
     /// Commit the lister: Query GitLab and return a list of projects.
-    pub fn list(&self) -> Projects {
+    pub fn list(&self) -> Result<Projects> {
         let query = self.build_query();
         debug!("query: {:?}", query);
 
-        let projects: Result<Projects, serde_json::Error> = self.gl.get(&query);
-
-        projects.unwrap()
+        self.gl.get(&query).chain_err(|| format!("cannot get query {}", query))
     }
 }
 
@@ -125,7 +124,7 @@ mod tests {
 
     #[test]
     fn build_query_default_split0() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects", TEST_PROJECT_ID);
@@ -138,7 +137,7 @@ mod tests {
 
     #[test]
     fn build_query_default_split1() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects", TEST_PROJECT_ID);
@@ -150,7 +149,7 @@ mod tests {
 
     #[test]
     fn build_query_default() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects", TEST_PROJECT_ID);
@@ -162,7 +161,7 @@ mod tests {
 
     #[test]
     fn build_query_archived() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?archived=true", TEST_PROJECT_ID);
@@ -177,7 +176,7 @@ mod tests {
 
     #[test]
     fn build_query_visibility() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?visibility=public", TEST_PROJECT_ID);
@@ -205,7 +204,7 @@ mod tests {
 
     #[test]
     fn build_query_order_by() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?order_by=id", TEST_PROJECT_ID);
@@ -255,7 +254,7 @@ mod tests {
 
     #[test]
     fn build_query_sort() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?sort=asc", TEST_PROJECT_ID);
@@ -270,7 +269,7 @@ mod tests {
 
     #[test]
     fn build_query_search() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?search=SearchPattern", TEST_PROJECT_ID);
@@ -284,7 +283,7 @@ mod tests {
 
     #[test]
     fn build_query_ci_enabled_first() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?ci_enabled_first=true", TEST_PROJECT_ID);
@@ -299,7 +298,7 @@ mod tests {
 
     #[test]
     fn build_query_multiple() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = format!("groups/{}/projects?archived=true&ci_enabled_first=true",
