@@ -21,13 +21,14 @@
 //! | `search` | string | no | Return list of authorized projects matching the search criteria |
 
 
-use serde_json;
 use serde_urlencoded;
 
 use BuildQuery;
 use Projects;
 use projects::{OwnedProjectListerInternal, ListingOrderBy};
 
+use ::errors::*;
+
 
 #[derive(Debug, Clone)]
 pub struct ProjectsLister<'a> {
@@ -75,14 +76,12 @@ impl<'a> ProjectsLister<'a> {
     }
 
     /// Commit the lister: Query GitLab and return a list of projects.
-    pub fn list(&self) -> Projects {
+    pub fn list(&self) -> Result<Projects> {
         // let query = serde_urlencoded::to_string(&self);
         let query = self.build_query();
         debug!("query: {:?}", query);
 
-        let projects: Result<Projects, serde_json::Error> = self.gl.get(&query);
-
-        projects.unwrap()
+        self.gl.get(&query).chain_err(|| format!("cannot get query {}", query))
     }
 }
 
@@ -112,7 +111,7 @@ mod tests {
     fn build_query_default() {
         let expected_string = "projects/owned";
 
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let projects_lister = gl.projects().owned();
@@ -126,7 +125,7 @@ mod tests {
 
     #[test]
     fn build_query_archived() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?archived=true";
@@ -149,7 +148,7 @@ mod tests {
 
     #[test]
     fn build_query_visibility() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?visibility=public";
@@ -177,7 +176,7 @@ mod tests {
 
     #[test]
     fn build_query_order_by() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?order_by=id";
@@ -226,7 +225,7 @@ mod tests {
 
     #[test]
     fn build_query_sort() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?sort=asc";
@@ -247,7 +246,7 @@ mod tests {
 
     #[test]
     fn build_query_search() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?search=SearchPattern";
@@ -261,7 +260,7 @@ mod tests {
 
     #[test]
     fn groups_build_query_multiple() {
-        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX");
+        let gl = ::GitLab::new(&"localhost", "XXXXXXXXXXXXXXXXXXXX").unwrap();
         // let gl: ::GitLab = Default::default();
 
         let expected_string = "projects/owned?archived=true&sort=desc";
